$ErrorActionPreference = 'STOP';

$packageName= 'azure-functions-core-tools'
$toolsDir   = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
$url_arm64      = 'https://functionscdn.azureedge.net/public/4.0.5611/Azure.Functions.Cli.win-arm64.4.0.5611.zip'
$url_x86        = 'https://functionscdn.azureedge.net/public/4.0.5611/Azure.Functions.Cli.win-x86.4.0.5611.zip'
$url_x64        = 'https://functionscdn.azureedge.net/public/4.0.5611/Azure.Functions.Cli.win-x64.4.0.5611.zip'
$checksum_arm64 = '5B1F99EB228565C585632A29F3F1606523FB1CB83E3A706F67561550D48BC776592FD0555F91582A5243B32F4144B90F8D0CDA128D33AB8D9BE06FCEA68964BE'
$checksum_x86   = '93FD560878114CC6FFB4CB1D8969D21857BA168E463B688036145A9293809CEC9201DB6DE7B27D5F10162218D74737B3DD68CEFDFC7524D7FC0B7D7FE5FC1EAF'
$checksum_x64   = 'FC994728A7CC876752DBCDFAACB32AD8D8B97688FB7CB439812338F2055757F07B3554E5C3B3730F15570D297D4B9C59E635B08993DF4CE3FDAD34465E758504'

# Get-PackageParameters returns a hash table array of values
$pp = Get-PackageParameters
# If specifically asked for x64 or arm64, we use that
if ($pp.ContainsKey('x64'))
{
  $url = $url_x64
  $checksum = $checksum_x64
}
elseif ($pp.ContainsKey('arm64'))
{
  $url =  $url_arm64
  $checksum = $checksum_arm64
}
else
{
  # By default, we want the x86 installer
  $url = $url_x86
  $checksum = $checksum_x86
}

$packageArgs = @{
  packageName   = $packageName
  unzipLocation = $toolsDir
  url           = $url
  checksum      = $checksum
  checksumType  = 'SHA512'
}

Install-ChocolateyZipPackage @packageArgs

# only symlink for func.exe
$files = Get-ChildItem $toolsDir -include *.exe -recurse
foreach ($file in $files) {
  if (!$file.Name.Equals("func.exe")) {
    #generate an ignore file
    New-Item "$file.ignore" -type file -force | Out-Null
  }
}

try {
  New-Item -type File -Path $toolsDir -Name "telemetryDefaultOn.sentinel" | Out-Null

  # show telemetry information
  ""
  "Telemetry"
  "---------"
  "The Azure Functions Core tools collect usage data in order to help us improve your experience."
  "The data is anonymous and doesn't include any user specific or personal information. The data is collected by Microsoft."
  ""
  "You can opt-out of telemetry by setting the FUNCTIONS_CORE_TOOLS_TELEMETRY_OPTOUT environment variable to '1' or 'true' using your favorite shell."
  ""
}
catch
{
  # That's ok
}
